import numpy as np
from pathlib import Path


def generate_point_clouds(n_samples, n_points, eps):
    sphere_point_clouds = [
        np.asarray(
            [
                [
                    np.cos(s) * np.cos(t) + eps * (np.random.rand(1)[0] - 0.5),
                    np.cos(s) * np.sin(t) + eps * (np.random.rand(1)[0] - 0.5),
                    np.sin(s) + eps * (np.random.rand(1)[0] - 0.5),
                ]
                for t in range(n_points)
                for s in range(n_points)
            ]
        )
        for _ in range(n_samples)
    ]
    # label spheres with 0
    sphere_labels = np.zeros(n_samples)

    torus_point_clouds = [
        np.asarray(
            [
                [
                    (2 + np.cos(s)) * np.cos(t) + eps * (np.random.rand(1)[0] - 0.5),
                    (2 + np.cos(s)) * np.sin(t) + eps * (np.random.rand(1)[0] - 0.5),
                    np.sin(s) + eps * (np.random.rand(1)[0] - 0.5)
                ]
                for t in range(n_points)
                for s in range(n_points)
            ]
        )
        for _ in range(n_samples)
    ]
    # label tori with 1
    torus_labels = np.ones(n_samples)

    point_clouds = np.concatenate((sphere_point_clouds, torus_point_clouds))
    labels = np.concatenate((sphere_labels, torus_labels))

    return point_clouds, labels


def make_gravitational_waves(
    path_to_data: Path,
    n_signals: int = 30,
    downsample_factor: int = 2,
    r_min: float = 0.075,
    r_max: float = 0.65,
    n_snr_values: int = 10,
        ):
    def padrand(V, n, kr):
        cut = np.random.randint(n)
        rand1 = np.random.randn(cut)
        rand2 = np.random.randn(n - cut)
        out = np.concatenate((rand1 * kr, V, rand2 * kr))
        return out

    Rcoef = np.linspace(r_min, r_max, n_snr_values)
    Npad = 500  # number of padding points on either side of the vector
    gw = np.load(path_to_data / "gravitational_wave_signals.npy")
    Norig = len(gw["data"][0])
    Ndat = len(gw["signal_present"])
    N = int(Norig / downsample_factor)

    ncoeff = []
    Rcoeflist = []

    for j in range(n_signals):
        ncoeff.append(10 ** (-19) * (1 / Rcoef[j % n_snr_values]))
        Rcoeflist.append(Rcoef[j % n_snr_values])

    noisy_signals = []
    gw_signals = []
    k = 0
    labels = np.zeros(n_signals)

    for j in range(n_signals):
        signal = gw["data"][j % Ndat][range(0, Norig, downsample_factor)]
        sigp = int((np.random.randn() < 0))
        noise = ncoeff[j] * np.random.randn(N)
        labels[j] = sigp
        if sigp == 1:
            rawsig = padrand(signal + noise, Npad, ncoeff[j])
            if k == 0:
                k = 1
        else:
            rawsig = padrand(noise, Npad, ncoeff[j])
        noisy_signals.append(rawsig.copy())
        gw_signals.append(signal)

    return noisy_signals, gw_signals, labels
